# The Brookhaven Group, LLC (TBG) Utilities
*Date and string utilities*

These are utilities commonoly used at The Brookhaven Group, LLC


### Installation

[PyPI Page](https://pypi.org/search/?q=tbgutils)

```shell
$ pip install tbgutils 
```

### Examples

